<?php
/**
 * DBCart 商城系统
 *
 * ==========================================================================
 * @link      https://www.dbcart.cn/
 * @copyright 北京珑大钜商科技有限公司，并保留所有权利。
 * @license   https://www.dbcart.cn/license.html License
 * ==========================================================================
 *
 * @author    静静的风 <baron@loongdom.cn>
 *
 */

namespace Admin\Controller;

use Admin\Data\Common;
use Admin\Service\Payment\PaymentForm;
use Laminas\Config\Writer\PhpArray;
use Laminas\Mvc\I18n\Translator;
use Laminas\View\Model\JsonModel;

class MachineTranslationController extends AdminActionController
{
    private $translator;

    public function __construct(
        Translator $translator
    )
    {
        $this->translator = $translator;
    }

    /**
     * 智能翻译列表
     * @return array
     */
    public function indexAction(): array
    {
        $translateArray = [];
        $filePath       = 'data/moduleData/Translate/';
        if (is_dir($filePath)) {
            $dh = scandir($filePath);
            foreach ($dh as $fileName) {
                if (!in_array($fileName, ['.', '..', '.DS_Store']) && stripos($fileName, '.php') !== false) {
                    $translationInfo = include($filePath . basename($fileName));
                    $translateArray[] = $translationInfo;
                }
            }
        }

        return ['translateArray' => $translateArray];
    }

    /**
     * 编辑设置翻译
     * @return array|\Laminas\Http\Response
     */
    public function editAction()
    {
        $translateName  = ucfirst(basename($this->params()->fromRoute('name', '')));
        $filePath       = 'data/moduleData/Translate/';
        $fileName       = $translateName . '.php';
        if(!file_exists($filePath . $fileName)) return $this->adminCommon()->toReferer();

        $configArray= include $filePath . $fileName;

        if($this->getRequest()->isPost()) {
            $translateArray = $this->request->getPost()->toArray();
            $translateArray['translationName'] = $configArray['translationName']['content'];
            $translateConfig = Common::readConfigFile('translate');

            $write = new PhpArray();
            $write->setUseBracketArraySyntax(true);
            $write->toFile($filePath . $fileName, PaymentForm::setFormValue($configArray, $translateArray));
            Common::opcacheInvalidate($filePath . $fileName);

            if ($translateArray['translationState'] == 1 && is_dir($filePath)) {
                $dh = scandir($filePath);
                foreach ($dh as $fileName) {
                    if (!in_array($fileName, ['.', '..', '.DS_Store']) && stripos($fileName, '.php') !== false) {
                        $translationInfo = include($filePath . basename($fileName));
                        if ($translationInfo['editAction'] == $translateName) continue;
                        $translationInfo['translationState']['checked'] = 0;
                        $write->toFile($filePath . $fileName, $translationInfo);
                        Common::opcacheInvalidate($filePath . $fileName);
                    }
                }
            }

            if ($translateArray['translationState'] == 1 || $translateConfig['translateType'] == $translateName) {
                $write->toFile('data/moduleData/System/translate.php', array_merge(['translateType' => $translateName], $translateArray));
                Common::opcacheInvalidate($filePath . $fileName);
            }

            $this->adminCommon()->addOperLog($this->translator->translate('翻译方式设置成功!'), $this->translator->translate('智能翻译'));

            return $this->redirect()->toRoute('machine-translation');
        }

        $translateInput = PaymentForm::createFormInput($configArray);

        return ['translateCode' => $translateName, 'formInput' => $translateInput];
    }

    /**
     * ajax翻译
     * @return JsonModel
     */
    public function ajaxMachineTranslationAction(): JsonModel
    {
        $fromText       = $this->params()->fromPost('fromText', '');
        $fromLanguage   = $this->params()->fromPost('fromLanguage', '');
        $toLanguage     = $this->params()->fromPost('toLanguage', '');

        if (empty($fromText)) return new JsonModel(['state' => 'false', 'message' => $this->translator->translate('主内容不能为空')]);

        $translateConfig = Common::readConfigFile('translate');
        if (!isset($translateConfig['translationState']) || $translateConfig['translationState'] != 1) return new JsonModel(['state' => 'false', 'message' => $this->translator->translate('智能翻译未启用')]);

        $translateName      = 'Admin\\Service\\Translate\\' . ucfirst($translateConfig['translateType']) . 'Translate';
        $translateService   = new $translateName($translateConfig);
        $transResult        = $translateService->cartTranslateBody($fromText, $fromLanguage, $toLanguage);

        if ($transResult != null) return new JsonModel($transResult);

        return new JsonModel(['state' => 'false', 'message' => $this->translator->translate('翻译失败，请确认配置正确')]);
    }
}