<?php
/**
 * DBCart 商城系统
 *
 * ==========================================================================
 * @link      https://www.dbcart.cn/
 * @copyright 北京珑大钜商科技有限公司，并保留所有权利。
 * @license   https://www.dbcart.cn/license.html License
 * ==========================================================================
 *
 * @author    静静的风 <baron@loongdom.cn>
 *
 */

namespace Cms\Form;

use Cms\Validator\CmsClassValidator;
use Laminas\Form\Form;

class CmsClassForm extends Form
{
    private $entityManager;
    private $cmsClass;

    public function __construct($entityManager = null, $cmsClass = null, $name = 'cms-class-form', $options = [])
    {
        parent::__construct($name, $options);
        $this->setAttribute('method', 'post');
        $this->setAttribute('class', 'form-horizontal');

        $this->entityManager= $entityManager;
        $this->cmsClass     = $cmsClass;

        $this->addElements();
        $this->addInputFilter();
    }

    protected function addElements()
    {
        foreach (SHOP_LANGUAGE as $language) {
            $this->add([
                'type'  => 'text',
                'name'  => 'cmsClassName'.$language,
                'attributes'    => [
                    'id'            => 'cmsClassName'.$language,
                    'class'         => 'form-control'
                ]
            ]);

            $this->add([
                'type'  => 'text',
                'name'  => 'cmsClassExtendName'.$language,
                'attributes'    => [
                    'id'            => 'cmsClassExtendName'.$language,
                    'class'         => 'form-control'
                ]
            ]);

            $this->add([
                'type'  => 'text',
                'name'  => 'cmsClassKeywords'.$language,
                'attributes'    => [
                    'id'            => 'cmsClassKeywords'.$language,
                    'class'         => 'form-control'
                ]
            ]);

            $this->add([
                'type'  => 'textarea',
                'name'  => 'cmsClassDescription'.$language,
                'attributes'    => [
                    'id'            => 'cmsClassDescription'.$language,
                    'class'         => 'form-control',
                    'rows'          => 4
                ]
            ]);
        }

        $this->add([
            'type'  => 'select',
            'name'  => 'cmsClassTopId',
            'attributes'    => [
                'id'            => 'cmsClassTopId',
                'class'         => 'form-control'
            ]
        ]);

        $this->add([
            'type'  => 'checkbox',
            'name'  => 'cmsClassState',
            'attributes'    => [
                'id'            => 'cmsClassState',
                'value'         => 1
            ]
        ]);

        $this->add([
            'type'  => 'number',
            'name'  => 'cmsClassSort',
            'attributes'    => [
                'id'        => 'cmsClassSort',
                'class'     => 'form-control',
                'value'     => 255,
                'min'       => 1
            ]
        ]);

        $this->add([
            'type'  => 'checkbox',
            'name'  => 'indexNews',
            'attributes'    => [
                'id'            => 'indexNews'
            ]
        ]);
    }

    protected function addInputFilter()
    {
        $inputFilter = $this->getInputFilter();

        foreach (SHOP_LANGUAGE as $language) {
            $inputFilter->add([
                'name'      => 'cmsClassName'.$language,
                'required'  => true,
                'filters'   => [
                    ['name' => 'StringTrim'],
                    ['name' => 'StripTags']
                ],
                'validators'=> [
                    [
                        'name'      => 'StringLength',
                        'options'   => [
                            'min'   => 1,
                            'max'   => 200
                        ]
                    ]
                ]
            ]);

            $inputFilter->add([
                'name'      => 'cmsClassExtendName'.$language,
                'required'  => false,
                'filters'   => [
                    ['name' => 'StringTrim'],
                    ['name' => 'StripTags']
                ],
                'validators'=> [
                    [
                        'name'      => 'StringLength',
                        'options'   => [
                            'min'   => 1,
                            'max'   => 200
                        ]
                    ]
                ]
            ]);

            $inputFilter->add([
                'name'      => 'cmsClassKeywords'.$language,
                'required'  => false,
                'filters'   => [
                    ['name' => 'StringTrim'],
                    ['name' => 'StripTags']
                ],
                'validators'=> [
                    [
                        'name'      => 'StringLength',
                        'options'   => [
                            'min'   => 1,
                            'max'   => 200
                        ]
                    ]
                ]
            ]);

            $inputFilter->add([
                'name'      => 'cmsClassDescription'.$language,
                'required'  => false,
                'filters'   => [
                    ['name' => 'StringTrim'],
                    ['name' => 'StripTags']
                ],
                'validators'=> [
                    [
                        'name'      => 'StringLength',
                        'options'   => [
                            'min'   => 1,
                            'max'   => 500
                        ]
                    ]
                ]
            ]);
        }

        $inputFilter->add([
            'name'      => 'cmsClassTopId',
            'required'  => true,
            'filters'   => [
                ['name' => 'ToInt']
            ],
            'validators'=> [
                [
                    'name'      => CmsClassValidator::class,
                    'options'   => [
                        'entityManager' => $this->entityManager,
                        'cmsClass'      => $this->cmsClass
                    ]
                ]
            ]
        ]);

        $inputFilter->add([
            'name'      => 'cmsClassState',
            'required'  => false,
            'validators'=> [
                [
                    'name'      => 'InArray',
                    'options'   => [
                        'haystack'  => [0, 1]
                    ]
                ]
            ]
        ]);

        $inputFilter->add([
            'name'      => 'cmsClassSort',
            'required'  => true,
            'filters'   => [
                ['name' => 'ToInt']
            ],
            'validators'=> [
                [
                    'name'      => 'GreaterThan',
                    'options'   => [
                        'min'   => 0
                    ]
                ]
            ]
        ]);

        $inputFilter->add([
            'name'      => 'indexNews',
            'required'  => false,
            'validators'=> [
                [
                    'name'      => 'InArray',
                    'options'   => [
                        'haystack'  => [0, 1]
                    ]
                ]
            ]
        ]);
    }
}