<?php
/**
 * DBCart 商城系统
 *
 * ==========================================================================
 * @link      https://www.dbcart.cn/
 * @copyright 北京珑大钜商科技有限公司，并保留所有权利。
 * @license   https://www.dbcart.cn/license.html License
 * ==========================================================================
 *
 * @author    静静的风 <baron@loongdom.cn>
 *
 */

namespace Goods\Repository;

use Doctrine\ORM\EntityRepository;
use Doctrine\ORM\Query\Expr\Join;
use Goods\Entity\Goods;
use Goods\Entity\GoodsBrand;
use Goods\Entity\GoodsBrandContent;

class GoodsBrandRepository extends EntityRepository
{
    /**
     * 品牌列表，主要用于后台
     * @return float|int|mixed|string
     */
    public function findAllBrand()
    {
        $query = $this->getEntityManager()->createQueryBuilder();
        $query->select('b', 'c.brandName')
            ->addSelect('(SELECT COUNT(g.goodsId) FROM '.Goods::class.' AS g WHERE g.brandId = b.brandId) AS goodsNum')
            ->from(GoodsBrand::class, 'b')
            ->leftJoin(GoodsBrandContent::class, 'c', Join::WITH, 'b.brandId = c.brandId')
            ->where('c.languageCode = :languageCode')->setParameter('languageCode', SHOP_FONT_LANGUAGE)
            ->orderBy('b.brandSort', 'ASC');

        return $query->getQuery()->getResult();
    }

    /**
     * 品牌列表options
     * @return float|int|mixed|string
     */
    public function findGoodsBrandOptions()
    {
        $query = $this->getEntityManager()->createQueryBuilder();
        $query->select('b', 'c.brandName')
            ->from(GoodsBrand::class, 'b')
            ->leftJoin(GoodsBrandContent::class, 'c', Join::WITH, 'b.brandId = c.brandId')
            ->where('c.languageCode = :languageCode')->setParameter('languageCode', SHOP_FONT_LANGUAGE)
            ->orderBy('b.brandSort', 'ASC')
            ->addOrderBy('b.brandId', 'ASC');

        return $query->getQuery()->getResult();
    }

    /*===================================前台商品品牌===================================*/
    public function findShopGoodsBrandList($languageCode)
    {
        $query = $this->getEntityManager()->createQueryBuilder();
        $query->select('b', 'c.brandName', 'c.brandNameExtend', 'c.brandKeywords', 'c.brandDescription', 'c.brandInfo')
            ->from(GoodsBrand::class, 'b')
            ->leftJoin(GoodsBrandContent::class, 'c', Join::WITH, 'b.brandId = c.brandId')
            ->where('c.languageCode = :languageCode')->setParameter('languageCode', $languageCode)
            ->orderBy('b.brandSort', 'ASC');

        return $query->getQuery()->getResult();
    }
}