<?php
/**
 * DBCart 商城系统
 *
 * ==========================================================================
 * @link      https://www.dbcart.cn/
 * @copyright 北京珑大钜商科技有限公司，并保留所有权利。
 * @license   https://www.dbcart.cn/license.html License
 * ==========================================================================
 *
 * @author    静静的风 <baron@loongdom.cn>
 *
 */

namespace Goods\Service;

use Doctrine\ORM\EntityManager;
use Goods\Entity\GoodsClassContent;

class GoodsClassContentManager
{
    private $entityManager;

    public function __construct(
        EntityManager $entityManager
    )
    {
        $this->entityManager = $entityManager;
    }

    /**
     * 添加和编辑商品分类内容
     * @param array $data
     * @param $classId
     * @return void
     * @throws \Doctrine\ORM\ORMException
     * @throws \Doctrine\ORM\OptimisticLockException
     */
    public function addOrEditGoodsClassContent(array $data, $classId)
    {
        foreach (SHOP_LANGUAGE as $language) {
            $classContent   = $this->entityManager->getRepository(GoodsClassContent::class)->findOneBy(['classId' => $classId, 'languageCode' => $language]);
            $emptyState     = false;
            if ($classContent == null) {
                $classContent = new GoodsClassContent();
                $classContent->setLanguageCode($language);
                $classContent->setClassId($classId);
                $emptyState = true;

            }
            $classContent->setClassName($data['className'.$language]);
            $classContent->setClassInfo($data['classInfo'.$language]);
            $classContent->setClassExtend($data['classExtend'.$language]);
            $classContent->setClassKeywords($data['classKeywords'.$language]);
            $classContent->setClassDescription($data['classDescription'.$language]);

            if ($emptyState) $this->entityManager->persist($classContent);

            $this->entityManager->flush();
        }
    }

    /**
     * 删除商品分类内容
     * @param $classId
     * @return void
     */
    public function deleteGoodsClassContent($classId)
    {
        $qb = $this->entityManager->createQueryBuilder();
        $qb->delete(GoodsClassContent::class, 'c')->where($qb->expr()->eq('c.classId', $classId));
        $qb->getQuery()->execute();
    }
}