<?php
/**
 * DBShop 电子商务系统
 *
 * ==========================================================================
 * @link      https://www.dbshop.net/
 * @copyright 北京珑大钜商科技有限公司，并保留所有权利。
 * @license   https://www.dbshop.net/license.html License
 * ==========================================================================
 *
 * @author    静静的风 <baron@loongdom.cn>
 *
 */

namespace User\Service\Common\AppLogin;

use Admin\Data\Common;
use Laminas\Json\Json;
use Laminas\Session\Container;

class GoogleLogin
{
    const ACCOUNTS_AUTH_URL = 'https://accounts.google.com/o/oauth2/v2/auth';
    const AUTH_USERINFO_URL = 'https://www.googleapis.com/oauth2/v2/userinfo';

    public $redirectUri;

    private $customerConfig = [];
    private $loginSession;

    public function __construct()
    {
        $this->customerConfig   = Common::readConfigFile('customer');
        $this->loginSession     = new Container('googleSession');
    }

    public function toLogin()
    {
        $loginKey = [
            'scope'                     => 'https://www.googleapis.com/auth/userinfo.email',
            'include_granted_scopes'    => 'true',
            'response_type'             => 'token',
            'state'                     => md5(uniqid(rand(), TRUE)),
            'redirect_uri'              => $this->redirectUri,
            'client_id'                 => $this->customerConfig['google_app_id']
        ];

        $this->loginSession->offsetSet('googleState', $loginKey['state']);

        header("Location: " . $this->combineUrl(self::ACCOUNTS_AUTH_URL, $loginKey));
        exit();
    }

    public function loginCallBack()
    {
        if (isset($_GET['state'])) {
            if ($this->loginSession->offsetGet('googleState') != $_GET['state']) {
                exit('<h2>The state does not match. You may be a victim of CSRF.</h2>');
            }

            $loginKey = [
                'access_token' => $_GET['access_token']
            ];

            $response   = Common::httpGet($this->combineUrl(self::AUTH_USERINFO_URL, $loginKey));
            $result     = Json::decode($response);
            if (isset($result->id) && isset($result->email)) {
                $this->loginSession->offsetSet('googleOpenId', $result->id);
                $this->loginSession->offsetSet('googleEmail', $result->email);
            } else exit($response);
        } else {
            echo "<script>let url = window.location.href; let index = url.lastIndexOf('#'); let queryUrl = url.substring(index +1); if(queryUrl.indexOf('state=') != -1) { window.location.href = url.substring(0, index) + '?' + queryUrl;}</script>";
            exit;
        }
    }

    /**
     * openId
     * @return mixed|null
     */
    public function openId()
    {
        return $this->loginSession->offsetGet('googleOpenId');
    }

    /**
     * unionId
     * @return string
     */
    public function unionId()
    {
        return '';
    }

    /**
     * 账户信息
     * @return array
     */
    public function loginUserInfo()
    {
        $userArray = explode('@', $this->loginSession->offsetGet('googleEmail'));

        return ['nickname' => $userArray[0]];
    }

    /**
     * 清除使用过的session
     */
    public function clearOtherLoginSession()
    {
        $this->loginSession->getManager()->getStorage()->clear($this->loginSession->getName());
    }

    /**
     * 拼接Url
     * @param $baseUrl
     * @param $keyArray
     * @return string
     */
    private function combineUrl($baseUrl, $keyArray)
    {
        return $baseUrl . '?' . Common::toUrlParams($keyArray);
    }
}